EdgeWithInversion

Trait EdgeWithInversion 

pub trait EdgeWithInversion: Edge {
    // Required methods
    fn is_inverted(&self) -> bool;
    fn invert(self) -> Self;

    // Provided methods
    fn invert_if(self, condition: bool) -> Self { ... }
    fn non_inverted(self) -> Self { ... }
}
Trait for an edge ID which encodes an optional inversion of the signal.

Required Methods

fn is_inverted(&self) -> bool

Check if the signal is inverted along the edge.

fn invert(self) -> Self

Create the inverted version of this edge.

Provided Methods

fn invert_if(self, condition: bool) -> Self

Create the inverted version of this edge iff condition is set to true, otherwise return a copy of the edge.

fn non_inverted(self) -> Self

Get the non-inverted version of this edge.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors