pub trait EdgeWithInversion: Edge {
// Required methods
fn is_inverted(&self) -> bool;
fn invert(self) -> Self;
// Provided methods
fn invert_if(self, condition: bool) -> Self { ... }
fn non_inverted(self) -> Self { ... }
}Expand description
Trait for an edge ID which encodes an optional inversion of the signal.
Required Methods
Sourcefn is_inverted(&self) -> bool
fn is_inverted(&self) -> bool
Check if the signal is inverted along the edge.
Provided Methods
Sourcefn invert_if(self, condition: bool) -> Self
fn invert_if(self, condition: bool) -> Self
Create the inverted version of this edge iff condition is set to true, otherwise return a copy of the edge.
Sourcefn non_inverted(self) -> Self
fn non_inverted(self) -> Self
Get the non-inverted version of this edge.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".